# R code used in:
# Do urban green spaces contain empty niches? A case study on epiphytic lichen communities

# Authors: Theo Llewellyn, Ester Gaya and David Murrell
# Journal: Diversity (2020)

# Contact information:
# t.llewellyn@kew.org
#

# The authors make no warranties about the R code below, and disclaim 
# liability for all uses of the R code, to the fullest extent 
# permitted by applicable law.


##############################################
#Import and prepare data

lichen_data <- read.csv("Dataset_1_LDV.csv")
attach(lichen_data)
head(lichen_data)
tail(lichen_data)

# deleting rows and columns not used in analysis
lichen_data <- lichen_data[1:496,]
lichen_data$Black.lichen.sp. <- NULL
lichen_data$Unknown.1 <- NULL
lichen_data$Sum.frequencies <- NULL
lichen_data$Mean.frequency <- NULL
lichen_data$Lichen.Diversity.Value <- NULL


# merging Physcia into one species
lichen_data$Physcia.spp <- lichen_data$Physcia.adscendens + lichen_data$Physcia.tenella
# replacing LDV values greater than 5 with 5
Physcia <- gsub(pattern = "6|7|8|9|10", replacement = "5", x = lichen_data$Physcia.spp)
lichen_data$Physcia.spp <- as.numeric(Physcia)
lichen_data$Physcia.adscendens <- NULL
lichen_data$Physcia.tenella <- NULL

##############################################



##############################################
#FIGURE 2
# total abundance for each species
total_abundance <- as.data.frame(colSums(lichen_data[,11:34]))
total_abundance$Species <- rownames(total_abundance)
total_abundance$Species <- c("Xanthoria parietina", "Amandinea punctata", "Candelariella reflexa", "Lepraria sp.", "Lecanora chlarotera", "Phaeophyscia orbicularis", "Flavoparmelia caperata", "Punctelia subrudecta", "Ramalina farinacea", "Evernia prunastri", "Parmelia sulcata", "Parmotrema perlatum", "Melanelixia subaurifera", "Candelaria concolor", "Lecidella elaeochroma", "Arthonia radiata", "Lecanora sp.", "Diploicia canescens", "Opegrapha vulgata", "Lepra albescens", "Graphis scripta", "Lecanora symmicta", "Physconia grisea", "Physcia spp")

total_abundance$Total_abundance <- total_abundance$`colSums(lichen_data[, 11:34])`

library(ggplot2)
tiff('FIGURE_2.tiff', units = "in", width = 6, height = 4, res = 300)
ggplot(total_abundance, aes(x = reorder(total_abundance$Species, -Total_abundance), y = Total_abundance)) + geom_col(fill = "darkgrey") + theme_classic() + labs(x = "Species", y = "Total abundance") + theme(axis.text.x = element_text(angle = 60, hjust = 1, face = "italic"))
dev.off()

##############################################



##############################################
#Calculate Lichen Diversity Value (LDV)

lichen_data$Mean_frequency <- rowMeans(lichen_data[,11:34])
# calculating the LDV by summing the means of the NSEW faces for each tree
LDV <- c()
seq(from = 1, to = 496, by = 4)
for (i in seq(from = 1, to = 496, by = 4)){
  LDV[i] <- lichen_data$Mean_frequency[i] + lichen_data$Mean_frequency[i+1] + 
    lichen_data$Mean_frequency[i+2] + lichen_data$Mean_frequency[i+3]
}
# appends 3 NAs so LDV is the same length as lichen_data
LDV <- append(LDV, c(NA,NA,NA))
lichen_data$LDV <- LDV

#summary stats
mean(na.exclude(LDV))
max(na.exclude(LDV))
min(na.exclude(LDV))
sd(na.exclude(LDV))

##############################################



##############################################
#Generalized linear modelling Lichen Diversity Value (LDV)

# making a new table with just the LDV data and the other measured variables for each tree
LDV_data <- lichen_data[seq(from = 1, to = 496, by = 4),c(1:9,35:36)]
attach(LDV_data)


# Full glm with GAMMA distribution
glm_mod <- glm(formula = 1+LDV ~ Circumference..cm. + Species + Park + Species:Circumference..cm. + factor(Rugosity) + Species:factor(Rugosity) + Circumference..cm.:factor(Rugosity) + Distance.to.nearest.tree..m. + Distance.to.nearest.Quercus..m. + Number.of.trees.within.10m, 
               data = LDV_data,
               family = Gamma(link = "log"))
#F-test to test significance of variables
drop1(glm_mod, test = "F")
#make Table S2
write.csv(round(drop1(glm_mod, test = "F"),3), file="TABLE_S2.csv",sep=",",row.names=F)


#removing highest non-significant p-value variable (Species:factor(Rugosity))
glm_mod_m1 <- glm(formula = 1+LDV ~ Circumference..cm. + Species + Park + Species:Circumference..cm. + factor(Rugosity) + Circumference..cm.:factor(Rugosity) + Distance.to.nearest.tree..m. + Distance.to.nearest.Quercus..m. + Number.of.trees.within.10m, 
                  data = LDV_data,
                  family = Gamma(link = "log"))
#F-test to test significance of variables
drop1(glm_mod_m1, test = "F")

#removing highest non-significant p-value variable (Distance.to.nearest.tree..m.)
glm_mod_m2 <- glm(formula = 1+LDV ~ Circumference..cm. + Species + Park + Species:Circumference..cm. + factor(Rugosity) + Circumference..cm.:factor(Rugosity) + Distance.to.nearest.Quercus..m. + Number.of.trees.within.10m, 
                  data = LDV_data,
                  family = Gamma(link = "log"))
#F-test to test significance of variables
drop1(glm_mod_m2, test = "F")

#removing highest non-significant p-value variable (Circumference..cm.:Species)
glm_mod_m3 <- glm(formula = 1+LDV ~ Circumference..cm. + Species + Park + factor(Rugosity) + Circumference..cm.:factor(Rugosity) + Distance.to.nearest.Quercus..m. + Number.of.trees.within.10m, 
                  data = LDV_data,
                  family = Gamma(link = "log"))
#F-test to test significance of variables
drop1(glm_mod_m3, test = "F")

#removing highest non-significant p-value variable (Distance.to.nearest.Quercus..m.)
glm_mod_m4 <- glm(formula = 1+LDV ~ Circumference..cm. + Species + Park + factor(Rugosity) + Circumference..cm.:factor(Rugosity) + Number.of.trees.within.10m, 
                  data = LDV_data,
                  family = Gamma(link = "log"))
#F-test to test significance of variables
drop1(glm_mod_m4, test = "F")

#removing highest non-significant p-value variable (Park)
glm_mod_m5 <- glm(formula = 1+LDV ~ Circumference..cm. + Species+ factor(Rugosity) + Circumference..cm.:factor(Rugosity) + Number.of.trees.within.10m, 
                  data = LDV_data,
                  family = Gamma(link = "log"))
#F-test to test significance of variables
drop1(glm_mod_m5, test = "F")

#removing highest non-significant p-value variable (Circumference..cm.:factor(Rugosity))
glm_mod_m6 <- glm(formula = 1+LDV ~ Circumference..cm. + Species + factor(Rugosity) + Number.of.trees.within.10m, 
                  data = LDV_data,
                  family = Gamma(link = "log"))
#F-test to test significance of variables
drop1(glm_mod_m6, test = "F")

#removing highest non-significant p-value variable (factor(Rugosity))
glm_mod_m7 <- glm(formula = 1+LDV ~ Circumference..cm. + Species + Number.of.trees.within.10m, 
                  data = LDV_data,
                  family = Gamma(link = "log"))
#F-test to test significance of variables
drop1(glm_mod_m7, test = "F")


#make Table S3
write.csv(round(summary(glm_mod_m7)$coefficients, 3), "TABLE_S3.csv")

#summary table suggest no sig. diff. between species cerris rubra and palustris, therefore collapse into one
species.Factor1 <- ifelse(LDV_data$Species == "robur", "robur", "cerris_rubra_palustris")
LDV_data2 <- data.frame(species.Factor1,LDV_data)
glm_mod3 <- glm(formula = 1+LDV  ~ Circumference..cm. + species.Factor1 + Number.of.trees.within.10m, 
                data = LDV_data2,
                family = Gamma(link = "log"))
#F-test to test significance of variables
drop1(glm_mod3, test = "F")

#ANOVA to compare whether collapsing species makes a sig. diff
anova(glm_mod_m7, glm_mod3, test="F")

#make Table S4
write.csv(round(anova(glm_mod_m7, glm_mod3, test="F"),3), file="TABLE_S4.csv",sep=",",row.names=F)


#no significant difference (p=0.8298) therefore collapsed model becomes the final model
summary(glm_mod3)
#make Table 1
write.csv(round(summary(glm_mod3)$coefficients,3), file="TABLE1_coefficients.csv",sep=",",row.names=F)
confint(glm_mod3)
write.csv(round(confint(glm_mod3),3), file="TABLE1_confint.csv",sep=",",row.names=F)


#check for collinearity of variables
library(DescTools)
VIF(glm_mod3)

#computes various goodness of fit statistics
library(rcompanion)
compareGLM(glm_mod3)

#makes diagnostic plots in Figure S3 (also plots approximate Cook statistics against leverage/(1-leverage), and case plot of Cook statistic which are not shown in Figure S3)
library(boot)
gamma_diag <- glm.diag(glm_mod3)
tiff(filename = "FIGURE_S3.tiff", res = 300, width = 21, height = 21, units = "cm")
glm.diag.plots(glm_mod3, gamma_diag)
dev.off()


#make Figure 3
library(visreg)
library(gridExtra)
library(grid)

plot_b <- visreg(glm_mod3, "Number.of.trees.within.10m", by="species.Factor1",
            scale = "response",
            partial=FALSE,
            rug=FALSE,
            gg = TRUE,
            overlay = TRUE)  + 
  geom_point(data = LDV_data2, aes(y = LDV + 1, x = Number.of.trees.within.10m, col = species.Factor1)) +
  scale_colour_manual(values=c("#56B4E9","#D55E00"), labels = c("Quercus cerris/rubra/palustris", "Quercus robur")) +
  scale_fill_manual(values=alpha(c("#56B4E9","#D55E00"),0.4)) +
  theme_grey() +
  scale_x_continuous(name = "Number trees within 10 m", breaks = seq(0,9,1), limits=c(0, 9)) +
  scale_y_continuous(name = "", limits=c(0.5, 5)) +
  theme(axis.ticks.length = unit(0.1, "cm"),
        axis.text.x = element_text(vjust = -1, 
                                   margin = margin(b = 5)),
        axis.text.y = element_text(margin = margin(r = 5)),
        aspect.ratio = 1,
        legend.text = element_text(face = "italic"),
        legend.position = c(0.735, 0.863),
        legend.background = element_blank()) +
  coord_fixed() +
  labs(color = "Collapsed species") +
  guides(fill=FALSE, colour = guide_legend(reverse=TRUE))


plot_a <- visreg(glm_mod3, "Circumference..cm.", by="species.Factor1",
            scale = "response",
            partial=FALSE,
            rug=FALSE,
            gg = TRUE,
            overlay = TRUE) +
  geom_point(data = LDV_data2, aes(y = LDV + 1, x = Circumference..cm., col = species.Factor1)) +
  scale_colour_manual(values=c("#56B4E9","#D55E00"), labels = c("Q. cerris/rubra/palustris", "Quercus robur")) +
  scale_fill_manual(values=alpha(c("#56B4E9","#D55E00"),0.4)) +
  theme_grey() +
  scale_x_continuous(name = " Tree Circumference (cm)", limits=c(50, 500)) +
  scale_y_continuous(name = "Lichen Diversity Value (LDV) + 1", limits=c(0.5, 5)) +
  theme(axis.ticks.length = unit(0.1, "cm"),
        axis.text.x = element_text(vjust = -1, 
                                   margin = margin(b = 5)),
        axis.text.y = element_text(margin = margin(r = 5)),
        aspect.ratio = 1,
        legend.text = element_text(face = "italic"),
        legend.position = c(0.7691, 0.895),
        legend.background = element_blank()) +
  coord_fixed() +
  labs(color = "Collapsed species") +
  guides(fill=FALSE, colour = guide_legend(reverse=TRUE))

#set layout for plot
layout1 <- rbind(c(1,2))

#plot Figure 3
tiff("FIGURE_3.tiff", res = 300, height = 297, width = 210, units = "mm")
grid.arrange(plot_a, plot_b + theme(legend.position="none"),
             layout_matrix=layout1)
dev.off()

##############################################



##############################################
#Generalized linear modelling Functional Traits

library(FD)
library(wesanderson)

#import dataset
functional_traits <- read.csv("Dataset_2_Functional_traits.csv", header = TRUE)
#subset dataset to remove column of species names and set as row names
functional_traits_nonames <- functional_traits[,2:5]
rownames(functional_traits_nonames) <- colnames(lichen_data[,11:34])


#make a presence/absence version of the LDV dataset
# create empty matrix to store values
lichen_matrix <- matrix(nrow = 496, ncol = 24)

# create empty string to store the values of the inner loop
Species <- c()

# loop for the number of species
for (i in 11:34){
  # loop for number of rows adding each fourth value to the successive three
  for (j in seq(from = 1, to = 496, by = 4)){
    Species[j] <- lichen_data[j,i] + lichen_data[j+1,i] + 
      lichen_data[j+2,i] + lichen_data[j+3,i]
  }
  # puts the value from the inner loop in the respective column of the matrix with appended   NAs so its same length
  lichen_matrix[,i-10] <- append(Species, c(NA,NA,NA))
}

head(lichen_matrix)
tail(lichen_matrix)

# remove NA rows and save in a new matrix
unique_lichen_matrix <- lichen_matrix[seq(from = 1, to = 496, by = 4),]

# convert to presence/absence
presence_lichen_matrix <- unique_lichen_matrix
presence_lichen_matrix[presence_lichen_matrix>1]<-1
colnames(presence_lichen_matrix) <- colnames(lichen_data[,11:34])
colnames(unique_lichen_matrix) <- colnames(lichen_data[,11:34])
ncol(presence_lichen_matrix)

# make a table with the other environmental variables too
environmental_data <- lichen_data[c(seq(from = 1, to = 496, by = 4)),1:9]
#to convert species to collapsed species as with LDV glm
#environmental_data$species.Factor1 <- LDV_data2$species.Factor1[c(seq(from = 1, to = 496, by = 4))]

# remove any trees with no lichen
row_sums <- rowSums(presence_lichen_matrix)
# gives rows with sum of 0 
grep(pattern = "0", x = row_sums)

# using presence absence data on the lichen data minus the rows where the sum is 0
dbFD(x = functional_traits_nonames, a = presence_lichen_matrix[-c(12,50,94,100,102,122),])

#calculate CWM of all functional traits
CWM_all <- functcomp(x = functional_traits_nonames, a = presence_lichen_matrix[-c(12,50,94,100,102,122),], CWM.type = "all")
#calculate CWM of only the dominant functional traits
CWM_dom <- functcomp(x = functional_traits_nonames, 
                     a = presence_lichen_matrix[-c(12,50,94,100,102,122),])

head(CWM_all)

# convert CWM all to dataframe
df_cwm_all <- data.frame(CWM_all$Type.of.reproduction_Sex, CWM_all$Ac.Bas_Ac,environmental_data[-c(12, 50, 94, 100, 102, 122), c(2,3,5:9)])
head(df_cwm_all)

#linear modelling using the CWM
#CWM of sexual reproduction
funct_model_sex <- glm(CWM_all.Type.of.reproduction_Sex ~ Circumference..cm. + Species + Park + factor(Rugosity) + Species:factor(Rugosity) + Circumference..cm.:factor(Rugosity) + Distance.to.nearest.tree..m. + Distance.to.nearest.Quercus..m. + Number.of.trees.within.10m, 
                       data = df_cwm_all, 
                       family = binomial)
#Chi-squared test to test significance of variables
Chisq_table <- drop1(funct_model_sex, test = "Chisq")

#make Table S5
write.csv(round(Chisq_table,3), "TABLE_S5.csv")
summary(funct_model_sex)
#none of the variables are significant


#CWM of acidophilous pH preference
funct_model_ph <- glm(CWM_all.Ac.Bas_Ac ~ Circumference..cm. + Species + Park + factor(Rugosity) + Species:factor(Rugosity) + Circumference..cm.:factor(Rugosity) + Distance.to.nearest.tree..m. + Distance.to.nearest.Quercus..m. + Number.of.trees.within.10m, 
                      data = df_cwm_all, 
                      family = binomial)
#Chi-squared test to test significance of variables
Chisq_table_pH <- drop1(funct_model_ph, test = "Chisq")

#make Table S6
write.csv(round(Chisq_table_pH,3), "TABLE_S6.csv")
summary(funct_model_sex)
#none of the variables are significant

##############################################


##############################################
#Species co-occurrence analysis

library(cooccur)
library(reshape2)

#flip presence/absence matric
flipped <- t(presence_lichen_matrix)
rownames(flipped) <- c("Xanthoria parietina", "Amandinea punctata", "Candelariella reflexa", "Lepraria sp.", "Lecanora chlarotera", "Phaeophyscia orbicularis", "Flavoparmelia caperata", "Punctelia subrudecta", "Ramalina farinacea", "Evernia prunastri", "Parmelia sulcata", "Parmotrema perlatum", "Melanelixia subaurifera", "Candelaria concolor", "Lecidella elaeochroma", "Arthonia radiata", "Lecanora sp.", "Diploicia canescens", "Opegrapha vulgata", "Lepra albescens", "Graphis scripta", "Lecanora symmicta", "Physconia grisea", "Physcia spp")

#run co-occurrence analysis on flipped matrix
cooccur.lichens <- cooccur(mat = flipped, type = "spp_site", thresh = TRUE, spp_names = TRUE)

#summary of significant cooccurrences
summary(cooccur.lichens)
#summary at 0.025 level
nrow(subset(prob.table(cooccur.lichens), p_lt <0.025)) #-ve co-occurrences
nrow(subset(prob.table(cooccur.lichens), p_gt <0.025)) #+ve co-occurrences
#total number of significant co-occurrences (+ve, -ve and random)
nrow(prob.table(cooccur.lichens))


#Edited plot.co_occur function from package 'cooccur', which plots significant co-occurrences only when p < 0.025 instead of 0.05
plot.cooccur <-
  function(x, ...){
    
    ##
    allargs <- match.call(expand.dots = TRUE)
    plotrand <- allargs$plotrand
    plotrand <- ifelse(test = is.null(plotrand),yes = FALSE,no = plotrand)
    randsummary<- allargs$randsummary
    randsummary <- ifelse(test = is.null(randsummary),yes = FALSE,no = randsummary)
    
    ##
    
    dim <- x$species
    comat_pos <- comat_neg <- matrix(nrow=dim,ncol=dim)
    
    co_tab <- x$result
    for (i in 1:nrow(co_tab)){
      comat_pos[co_tab[i,"sp1"],co_tab[i,"sp2"]] <- co_tab[i,"p_gt"]
      comat_pos[co_tab[i,"sp2"],co_tab[i,"sp1"]] <- co_tab[i,"p_gt"]
      
      row.names(comat_pos[co_tab[i,"sp2"],co_tab[i,"sp1"]])
      
    }
    for (i in 1:nrow(co_tab)){
      comat_neg[co_tab[i,"sp1"],co_tab[i,"sp2"]] <- co_tab[i,"p_lt"]
      comat_neg[co_tab[i,"sp2"],co_tab[i,"sp1"]] <- co_tab[i,"p_lt"]
    }
    comat <- ifelse(comat_pos>=0.025,0,1) + ifelse(comat_neg>=0.025,0,-1)
    colnames(comat) <- 1:dim
    row.names(comat) <- 1:dim
    
    if ("spp_key" %in% names(x)){
      
      sp1_name <- merge(x=data.frame(order=1:length(colnames(comat)),sp1=colnames(comat)),y=x$spp_key,by.x="sp1",by.y="num",all.x=T)
      sp2_name <- merge(x=data.frame(order=1:length(row.names(comat)),sp2=row.names(comat)),y=x$spp_key,by.x="sp2",by.y="num",all.x=T)
      
      colnames(comat) <- sp1_name[with(sp1_name,order(order)),"spp"]  
      row.names(comat) <- sp2_name[with(sp2_name,order(order)),"spp"]
      
    }  
    
    #ind <- apply(comat, 1, function(x) all(is.na(x)))
    #comat <- comat[!ind,]
    #ind <- apply(comat, 2, function(x) all(is.na(x)))
    #comat <- comat[,!ind]
    
    comat[is.na(comat)] <- 0
    
    origN <- nrow(comat)
    
    # SECTION TO REMOVE SPECIES INTERACTION WITH NO OTHERS
    
    #rmrandomspp <- function(orimat,plotrand = FALSE,randsummary = FALSE){
    if(plotrand == FALSE){
      ind <- apply(comat, 1, function(x) all(x==0))
      comat <- comat[!ind,]    
      ind <- apply(comat, 2, function(x) all(x==0))
      comat <- comat[,!ind]
      #ind <- apply(orimat, 1, function(x) all(x==0))
      #orimat <- orimat[!ind,]    
      #ind <- apply(orimat, 2, function(x) all(x==0))
      #orimat <- orimat[,!ind]
    }
    #return(orimat)
    #}
    
    #comat <- rmrandomspp(orimat = comat, dots)
    ####################################################### 
    
    postN <- nrow(comat)
    
    
    comat <- comat[order(rowSums(comat)),]
    comat <- comat[,order(colSums(comat))]
    
    #comat <- rmrandomspp(orimat = comat, ...)
    
    #ind <- apply(comat, 1, function(x) all(x==0))
    #comat <- comat[!ind,]
    #ind <- apply(comat, 2, function(x) all(x==0))
    #comat <- comat[,!ind]
    
    ind <- apply(comat, 1, function(x) all(x==0))
    comat <- comat[names(sort(ind)),]
    ind <- apply(comat, 2, function(x) all(x==0))
    comat <- comat[,names(sort(ind))]
    
    #comat
    data.m = melt(comat)
    colnames(data.m) <- c("X1","X2","value")
    data.m$X1 <- as.character(data.m$X1)
    data.m$X2 <- as.character(data.m$X2)
    
    meas <- as.character(unique(data.m$X2))
    
    dfids <- subset(data.m, X1 == X2)
    
    X1 <- data.m$X1
    X2 <- data.m$X2
    
    df.lower = subset(data.m[lower.tri(comat),],X1 != X2)
    
    ##### testing the rand summary
    if(randsummary == FALSE){  
    }else{
      dim <- nrow(comat)
      ext.dim <- round(dim*0.2,digits = 0)
      if(ext.dim<0){ext.dim<-1}
      placehold <- paste("ext_", rep(c(1:ext.dim),each = dim), sep="")
      
      randcol.df <- data.frame(
        X1 = placehold,
        X2 = rep(meas,times = ext.dim),
        value = rep(x = c(-2), times = dim*ext.dim))
      
      df.lower <- rbind(df.lower,randcol.df)
      meas <- c(meas,unique(placehold))
    }
    
    
    
    
    #####
    
    X1 <- df.lower$X1
    X2 <- df.lower$X2
    value <- df.lower$value
    
    
    
    ####
    if(randsummary == FALSE){  
      p <- ggplot(df.lower, aes(X1, X2)) + geom_tile(aes(fill = factor(value,levels=c(-1,0,1))), colour ="white") 
      p <- p + scale_fill_manual(values = c("#FFCC66","dark gray","light blue"), name = "", labels = c("negative","random","positive"),drop=FALSE) + 
        theme(axis.text.x = element_blank(),axis.text.y = element_blank(),axis.ticks = element_blank(),plot.title = element_text(vjust=-4,size=20, face="bold"),panel.background = element_rect(fill='white', colour='white'),panel.grid.major = element_blank(), panel.grid.minor = element_blank(),legend.position = c(0.9, 0.5),legend.text=element_text(size=18)) + 
        ggtitle("Species Co-occurrence Matrix") + 
        xlab("") + ylab("") + 
        scale_x_discrete(limits=meas, expand = c(0.3, 0),drop=FALSE) + 
        scale_y_discrete(limits=meas, expand = c(0.3, 0),drop=FALSE) 
      p <- p + geom_text(data=dfids,aes(label=X1),hjust=1,vjust=0,angle = -22.5)#, color="dark gray")
      
      
    }else{
      
      p <- ggplot(df.lower, aes(X1, X2)) + geom_tile(aes(fill = factor(value,levels=c(-1,0,1,-2))), colour ="white") 
      p <- p + scale_fill_manual(values = c("#FFCC66","dark gray","light blue","light gray"), name = "", labels = c("negative","random","positive","random"),drop=FALSE) + 
        theme(axis.text.x = element_blank(),axis.text.y = element_blank(),axis.ticks = element_blank(),plot.title = element_text(vjust=-4,size=20, face="bold"),panel.background = element_rect(fill='white', colour='white'),panel.grid.major = element_blank(), panel.grid.minor = element_blank(),legend.position = c(0.9, 0.5),legend.text=element_text(size=18)) + 
        ggtitle("Species Co-occurrence Matrix") + 
        xlab("") + ylab("") + 
        scale_x_discrete(limits=meas, expand = c(0.3, 0),drop=FALSE) + 
        scale_y_discrete(limits=meas, expand = c(0.3, 0),drop=FALSE) 
      p <- p + geom_text(data=dfids,aes(label=X1),hjust=1,vjust=0,angle = -22.5)#, color="dark gray")
      
      dim <- nrow(comat)
      ext_x <- dim + 0.5 #(ext.dim/2)
      ext_y <- dim + 1
      nrem <- origN - postN
      randtext <- paste(nrem, " completely\nrandom species")
      ext_dat <- data.frame(ext_x=ext_x,ext_y=ext_y,randtext=randtext)
      
      p <- p + geom_text(data=ext_dat,aes(x = ext_x,y = ext_y,label=randtext),hjust=0,vjust=0, color="dark gray")
    }
    ####
    
    p
    
  }


#make co-occurrence matrix in Figure 4a
tiff('cooccur_0.025.tiff', units = "in", width = 8.5, height = 5.02, res = 300)
lichen_heatmap <- plot(cooccur.lichens)
lichen_heatmap <- lichen_heatmap + theme(legend.position = c(0.929,0.5),
                                         legend.background = element_blank(),
                                         plot.title = element_text(size=14, face="bold")) +
  ggtitle("(a)")
lichen_heatmap
dev.off()


#CLustering analysis

#rerun cooccurrence analysis with threshold set to FALSE to be able to make effect size matrix
cooccur.lichens_1 <- cooccur(mat = flipped, type = "spp_site", thresh = FALSE, spp_names = TRUE)
#make effect size matrix from results of cooccur with no threshold
eff_sizes <- effect.sizes(cooccur.lichens_1, standardized = TRUE, matrix = TRUE)
prob.table(cooccur.lichens_1)
#convert distance matrix to normal matrix
eff_size_matrix <- as.matrix(eff_sizes)

#for loop to keep only the species that are shown in the heatmap. i.e above the threshold
species_vec <- c("Arthonia radiata", "Diploicia canescens", "Lepra albescens", "Graphis scripta", "Lecanora symmicta" , "Physconia grisea")
rows <- c()
for (i in 1:length(species_vec)){
  rows[i] <- grep(pattern = species_vec[i], x = rownames(eff_size_matrix))
}
eff_size_matrix <- eff_size_matrix[-rows,-rows]

#convert back to distance matrix
eff_sizes <- as.dist(eff_size_matrix)

#Clustering analysis
library(vegan)
library(fpc)
library(cluster)
library(factoextra)
library(gridExtra)
library(grid)
library(lattice)

#run partitioned around mediod clustering on 1 - effect size matrix
cluster_output <- pam(1 - eff_sizes, k= 2, diss = TRUE)
cluster_output$data = eff_sizes

#plot the results of clustering analysis seen in Figure 4c
lichen_cluster <- fviz_cluster(cluster_output, repel = TRUE) + 
  scale_colour_manual(values=c("#CC79A7","#009E73")) +
  scale_fill_manual(values=alpha(c("#CC79A7","#009E73"),0.4)) +
  guides(fill = guide_legend(title = "cluster", override.aes = aes(label = ""))) +
  theme(plot.title = element_text(size=14, face="bold")) +
  ggtitle("(c)")


#combine Figure 4a and 4c leaving a blank space in the middle to insert manually drawn Figure 4b
blank_gg <- ggplot() + theme_void() + theme(plot.title = element_text(size=14, face="bold")) +
  ggtitle("(b)")

layout_cooccur <- rbind(c(1),
                        c(2),
                        c(3))
tiff("FIGURE_4_w_blank.tiff", res = 600, height = 297, width = 210, units = "mm")
grid.arrange(lichen_heatmap, blank_gg, lichen_cluster, layout_matrix=layout_cooccur, heights = c(2,1,2))
dev.off()


##############################################



##############################################
#plot rarefaction curves in Figure S2
library(vegan)

#subset dataset for each park
spaccumreg<-specaccum(unique_lichen_matrix[which(LDV_data$Park == 'regents'),])
spaccumrich<-specaccum(unique_lichen_matrix[which(LDV_data$Park == 'richmond'),])
spaccumvic<-specaccum(unique_lichen_matrix[which(LDV_data$Park == 'victoria'),])

tiff('FIGURE_S2.tiff', res = 600, height = 210, width = 297, units = "mm")
par(mfrow=c(2,2))
plot(spaccumreg, ylab = "Accumulative number of species")
plot(spaccumrich, ylab = "Accumulative number of species")
plot(spaccumvic, ylab = "Accumulative number of species")
dev.off()

par(mfrow=c(1,1))
